==> haskell-contravariant-1.5.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.5
visibility:           public
id:                   contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
key:                  contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  e8f4bca85b7e22dac00d0a14f7f858ba
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/contravariant-1.5.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/contravariant-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/contravariant-1.5.5
hs-libraries:         HScontravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
depends:
    StateVar-1.2.2-GxMRs6UXIRXHYwZG2fj94o base-4.15.1.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.5.5-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.5
visibility:           public
id:                   contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
key:                  contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  44fc0f872fe61beb0daaf847449113b4
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-9.2.8/site-local/contravariant-1.5.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/contravariant-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-contravariant
hs-libraries:         HScontravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
depends:
    StateVar-1.2.2-4TJ8CI5wrC5B2qk02v8ZQ3 base-4.16.4.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
